searchData={"content_type":"text/markdown","items":[{"doc":"<!-- INCLUDE -->\nA function decorator for OpenTelemetry traces.","ref":"OpenTelemetryDecorator.html","title":"OpenTelemetryDecorator","type":"module"},{"doc":"Add `open_telemetry_decorator` to your list of dependencies in `mix.exs`. We include the `opentelemetry_api` package, but you'll need to add `opentelemetry` yourself in order to report spans and traces.\n\n```elixir\ndef deps do\n  [\n    {:opentelemetry, \"~> 1.2\"},\n    {:opentelemetry_exporter, \"~> 1.4\"},\n    {:open_telemetry_decorator, \"~> 1.4\"}\n  ]\nend\n```\n\nThen follow the directions for the exporter of your choice to send traces to to zipkin, honeycomb, etc.\nhttps://github.com/open-telemetry/opentelemetry-erlang/tree/main/apps/opentelemetry_zipkin\n\n#","ref":"OpenTelemetryDecorator.html#module-installation","title":"Installation - OpenTelemetryDecorator","type":"module"},{"doc":"`config/runtime.exs`\n```elixir\napi_key = Map.fetch!(System.get_env(), \"HONEYCOMB_KEY\")\n\nconfig :opentelemetry, :processors,\n  otel_batch_processor: %{\n    exporter:\n      {:opentelemetry_exporter,\n       %{\n         protocol: :grpc,\n         headers: [\n           {'x-honeycomb-team', api_key},\n           {'x-honeycomb-dataset', 'YOUR_APP_NAME'}\n         ],\n         endpoints: [{:https, 'api.honeycomb.io', 443, []}]\n       }}\n  }\n\n```","ref":"OpenTelemetryDecorator.html#module-honeycomb-example","title":"Honeycomb Example - OpenTelemetryDecorator","type":"module"},{"doc":"Add `use OpenTelemetryDecorator` to the module, and decorate any methods you want to trace with `@decorate with_span(\"span name\")`.\n\nThe `with_span` decorator will automatically wrap the decorated function in an opentelemetry span with the provided name.\n\n```elixir\ndefmodule MyApp.Worker do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"worker.do_work\")\n  def do_work(arg1, arg2) do\n    ...doing work\n  end\nend\n```\n\n#","ref":"OpenTelemetryDecorator.html#module-usage","title":"Usage - OpenTelemetryDecorator","type":"module"},{"doc":"The `with_span` decorator allows you to specify an `include` option which gives you more flexibility with what you can include in the span attributes. Omitting the `include` option with `with_span` means no attributes will be added to the span by the decorator.\n\n```elixir\ndefmodule MyApp.Worker do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"worker.do_work\", include: [:arg1, :arg2])\n  def do_work(arg1, arg2) do\n    # ...doing work\n  end\nend\n```\n\nThe Attributes module includes a helper for setting additional attributes outside of the `include` option. Attributes added in either a `set` call or in the `include` that are not [primitive OTLP values](https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/common/README.md#attribute) will be converted to strings with `Kernel.inspect/1`.\n\n```elixir\ndefmodule MyApp.Worker do\n  use OpenTelemetryDecorator\n  alias OpenTelemetryDecorator.Attributes\n\n  @decorate with_span(\"worker.do_work\")\n  def do_work(arg1, arg2) do\n    Attributes.set(arg1: arg1, arg2: arg2)\n    # ...doing work\n    Attributes.set(:output, \"something\")\n  end\nend\n```\n\nThe decorator uses a macro to insert code into your function at compile time to wrap the body in a new span and link it to the currently active span. In the example above, the `do_work` method would become something like this:\n\n```elixir\ndefmodule MyApp.Worker do\n  require OpenTelemetry.Tracer, as: Tracer\n\n  def do_work(arg1, arg2) do\n    Tracer.with_span \"my_app.worker.do_work\" do\n      # ...doing work\n      Tracer.set_attributes(arg1: arg1, arg2: arg2)\n    end\n  end\nend\n```\n\n#","ref":"OpenTelemetryDecorator.html#module-span-attributes","title":"Span Attributes - OpenTelemetryDecorator","type":"module"},{"doc":"Honeycomb suggests that you [namespace custom fields](https://docs.honeycomb.io/getting-data-in/data-best-practices/#namespace-custom-fields), specifically putting manual instrumentation under `app.`\n\nIn order to do this, you'll configure the `attr_prefix` option in `config/config.exs`\n```elixir\nconfig :open_telemetry_decorator, attr_prefix: \"app.\"\n```\n\n#","ref":"OpenTelemetryDecorator.html#module-prefixing-span-attributes","title":"Prefixing Span Attributes - OpenTelemetryDecorator","type":"module"},{"doc":"By default, nested attributes are joined with an underscore. However, when you have an object with underscores and a property with underscores, this can be hard to visually parse. For example, `my_struct.other_struct.field`, would be exported as `my_struct_other_struct_field`.\n\nTo override this, you'll configure the `attr_joiner` option in `config/config.exs`. The default value will likely change from `_` to `.` in a future version.\n```elixir\nconfig :open_telemetry_decorator, attr_joiner: \".\"\n```\n\nThanks to @benregn for the examples and inspiration for these two options!","ref":"OpenTelemetryDecorator.html#module-changing-the-join-character-for-nested-attributes","title":"Changing the join character for nested attributes - OpenTelemetryDecorator","type":"module"},{"doc":"","ref":"OpenTelemetryDecorator.html#trace/1","title":"OpenTelemetryDecorator.trace/1","type":"macro"},{"doc":"","ref":"OpenTelemetryDecorator.html#trace/2","title":"OpenTelemetryDecorator.trace/2","type":"macro"},{"doc":"","ref":"OpenTelemetryDecorator.html#trace/4","title":"OpenTelemetryDecorator.trace/4","type":"function"},{"doc":"","ref":"OpenTelemetryDecorator.html#with_span/1","title":"OpenTelemetryDecorator.with_span/1","type":"macro"},{"doc":"","ref":"OpenTelemetryDecorator.html#with_span/2","title":"OpenTelemetryDecorator.with_span/2","type":"macro"},{"doc":"Decorate a function to add to or create an OpenTelemetry trace with a named span.\n\nYou can provide span attributes by specifying a list of variable names as atoms.\nThis list can include:\n\n- any variables (in the top level closure) available when the function exits,\n- the result of the function by including the atom `:result`,\n- map/struct properties using nested lists of atoms.\n\n```elixir\ndefmodule MyApp.Worker do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"my_app.worker.do_work\", include: [:arg1, [:arg2, :count], :total, :result])\n  def do_work(arg1, arg2) do\n    total = arg1.count + arg2.count\n    {:ok, total}\n  end\nend\n```","ref":"OpenTelemetryDecorator.html#with_span/4","title":"OpenTelemetryDecorator.with_span/4","type":"function"},{"doc":"","ref":"OpenTelemetryDecorator.Attributes.html","title":"OpenTelemetryDecorator.Attributes","type":"module"},{"doc":"","ref":"OpenTelemetryDecorator.Attributes.html#get/2","title":"OpenTelemetryDecorator.Attributes.get/2","type":"function"},{"doc":"","ref":"OpenTelemetryDecorator.Attributes.html#set/1","title":"OpenTelemetryDecorator.Attributes.set/1","type":"function"},{"doc":"","ref":"OpenTelemetryDecorator.Attributes.html#set/2","title":"OpenTelemetryDecorator.Attributes.set/2","type":"function"},{"doc":"","ref":"OpenTelemetryDecorator.Attributes.html#set/3","title":"OpenTelemetryDecorator.Attributes.set/3","type":"function"}]}